package com.os.ems.base.service.impl;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.stream.Collectors;

import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import com.os.ems.base.domain.TreeSelects;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.ems.base.mapper.EmsBaseWorkUnitMapper;
import com.os.ems.base.domain.EmsBaseWorkUnit;
import com.os.ems.base.service.IEmsBaseWorkUnitService;

/**
 * 统计单元信息Service业务层处理
 * 
 * @author Yinq
 * @date 2024-05-09
 */
@Service
public class EmsBaseWorkUnitServiceImpl implements IEmsBaseWorkUnitService 
{
    @Autowired
    private EmsBaseWorkUnitMapper emsBaseWorkUnitMapper;

    /**
     * 查询统计单元信息
     * 
     * @param objId 统计单元信息主键
     * @return 统计单元信息
     */
    @Override
    public EmsBaseWorkUnit selectEmsBaseWorkUnitByObjId(Long objId)
    {
        return emsBaseWorkUnitMapper.selectEmsBaseWorkUnitByObjId(objId);
    }

    /**
     * 查询统计单元信息列表
     * 
     * @param emsBaseWorkUnit 统计单元信息
     * @return 统计单元信息
     */
    @Override
    public List<EmsBaseWorkUnit> selectEmsBaseWorkUnitList(EmsBaseWorkUnit emsBaseWorkUnit)
    {
        return emsBaseWorkUnitMapper.selectEmsBaseWorkUnitList(emsBaseWorkUnit);
    }

    /**
     * 新增统计单元信息
     * 
     * @param emsBaseWorkUnit 统计单元信息
     * @return 结果
     */
    @Override
    public int insertEmsBaseWorkUnit(EmsBaseWorkUnit emsBaseWorkUnit)
    {
        emsBaseWorkUnit.setCreateTime(DateUtils.getNowDate());
        return emsBaseWorkUnitMapper.insertEmsBaseWorkUnit(emsBaseWorkUnit);
    }

    /**
     * 修改统计单元信息
     * 
     * @param emsBaseWorkUnit 统计单元信息
     * @return 结果
     */
    @Override
    public int updateEmsBaseWorkUnit(EmsBaseWorkUnit emsBaseWorkUnit)
    {
        emsBaseWorkUnit.setUpdateTime(DateUtils.getNowDate());
        return emsBaseWorkUnitMapper.updateEmsBaseWorkUnit(emsBaseWorkUnit);
    }

    /**
     * 批量删除统计单元信息
     * 
     * @param objIds 需要删除的统计单元信息主键
     * @return 结果
     */
    @Override
    public int deleteEmsBaseWorkUnitByObjIds(Long[] objIds)
    {
        return emsBaseWorkUnitMapper.deleteEmsBaseWorkUnitByObjIds(objIds);
    }

    /**
     * 删除统计单元信息信息
     * 
     * @param objId 统计单元信息主键
     * @return 结果
     */
    @Override
    public int deleteEmsBaseWorkUnitByObjId(Long objId)
    {
        return emsBaseWorkUnitMapper.deleteEmsBaseWorkUnitByObjId(objId);
    }

    @Override
    public List<TreeSelects> selectBaseWorkUnitTreeList(EmsBaseWorkUnit baseWorkUnit) {
        List<EmsBaseWorkUnit> baseWorkUnits = selectEmsBaseWorkUnitList(baseWorkUnit);
        return buildWorkUnitTreeSelect(baseWorkUnits);
    }

    @Override
    public List<TreeSelects> buildWorkUnitTreeSelect(List<EmsBaseWorkUnit> baseWorkUnits) {
        List<EmsBaseWorkUnit> baseWorkUnitsTrees = buildWorkUnitTree(baseWorkUnits);
        return baseWorkUnitsTrees.stream().map(TreeSelects::new).collect(Collectors.toList());
    }

    @Override
    public List<EmsBaseWorkUnit> buildWorkUnitTree(List<EmsBaseWorkUnit> baseWorkUnits) {
        List<EmsBaseWorkUnit> returnList = new ArrayList<EmsBaseWorkUnit>();
        List<Long> tempList = baseWorkUnits.stream().map(EmsBaseWorkUnit::getObjId).collect(Collectors.toList());
        for (EmsBaseWorkUnit baseWorkUnit : baseWorkUnits)
        {
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempList.contains(baseWorkUnit.getParentId()))
            {
                recursionFn(baseWorkUnits, baseWorkUnit);
                returnList.add(baseWorkUnit);
            }
        }
        if (returnList.isEmpty())
        {
            returnList = baseWorkUnits;
        }
        return returnList;
    }

    /**
     * 递归列表
     */
    private void recursionFn(List<EmsBaseWorkUnit> list, EmsBaseWorkUnit t)
    {
        // 得到子节点列表
        List<EmsBaseWorkUnit> childList = getChildList(list, t);
        t.setChildren(childList);
        for (EmsBaseWorkUnit tChild : childList)
        {
            if (hasChild(list, tChild))
            {
                recursionFn(list, tChild);
            }
        }
    }

    /**
     * 得到子节点列表
     */
    private List<EmsBaseWorkUnit> getChildList(List<EmsBaseWorkUnit> list, EmsBaseWorkUnit t)
    {
        List<EmsBaseWorkUnit> tlist = new ArrayList<EmsBaseWorkUnit>();
        Iterator<EmsBaseWorkUnit> it = list.iterator();
        while (it.hasNext())
        {
            EmsBaseWorkUnit n = (EmsBaseWorkUnit) it.next();
            if (StringUtils.isNotNull(n.getParentId()) && n.getParentId().longValue() == t.getObjId().longValue())
            {
                tlist.add(n);
            }
        }
        return tlist;
    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<EmsBaseWorkUnit> list, EmsBaseWorkUnit t)
    {
        return getChildList(list, t).size() > 0;
    }
}
