package com.os.mes.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.base.domain.BaseProductLine;
import com.os.mes.base.service.IBaseProductLineService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 产线/工位信息Controller
 * 
 * @author Yinq
 * @date 2024-05-10
 */
@RestController
@RequestMapping("/mes/base/baseProductLine")
public class BaseProductLineController extends BaseController
{
    @Autowired
    private IBaseProductLineService baseProductLineService;

    /**
     * 查询产线/工位信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseProductLine:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseProductLine baseProductLine)
    {
        startPage();
        List<BaseProductLine> list = baseProductLineService.selectBaseProductLineList(baseProductLine);
        return getDataTable(list);
    }

    /**
     * 查询产线/工位信息下拉框列表
     */
    @GetMapping("/getBaseProductLineList")
    public AjaxResult getBaseProductLineList(BaseProductLine baseProductLine)
    {
        List<BaseProductLine> list = baseProductLineService.selectBaseProductLineList(baseProductLine);
        return success(list);
    }

    /**
     * 导出产线/工位信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseProductLine:export')")
    @Log(title = "产线/工位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseProductLine baseProductLine)
    {
        List<BaseProductLine> list = baseProductLineService.selectBaseProductLineList(baseProductLine);
        ExcelUtil<BaseProductLine> util = new ExcelUtil<BaseProductLine>(BaseProductLine.class);
        util.exportExcel(response, list, "产线/工位信息数据");
    }

    /**
     * 获取产线/工位信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseProductLine:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(baseProductLineService.selectBaseProductLineByObjId(objId));
    }

    /**
     * 新增产线/工位信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseProductLine:add')")
    @Log(title = "产线/工位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseProductLine baseProductLine)
    {
        baseProductLine.setCreateBy(getUsername());
        return toAjax(baseProductLineService.insertBaseProductLine(baseProductLine));
    }

    /**
     * 修改产线/工位信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseProductLine:edit')")
    @Log(title = "产线/工位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseProductLine baseProductLine)
    {
        baseProductLine.setUpdateBy(getUsername());
        return toAjax(baseProductLineService.updateBaseProductLine(baseProductLine));
    }

    /**
     * 删除产线/工位信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseProductLine:remove')")
    @Log(title = "产线/工位信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(baseProductLineService.deleteBaseProductLineByObjIds(objIds));
    }
}
