package com.os.mes.base.domain;

import java.math.BigDecimal;
import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.os.common.annotation.Excel;
import com.os.common.core.domain.BaseEntity;

/**
 * 物料信息对象 base_material_info
 *
 * @author Yinq
 * @date 2024-05-10
 */
public class BaseMaterialInfo extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 主键标识
     */
    private Long objId;

    /**
     * 物料编码
     */
    @Excel(name = "物料编码")
    private String materialCode;

    /**
     * 物料名称
     */
    @Excel(name = "物料名称")
    private String materialName;

    /**
     * 物料大类
     */
    @Excel(name = "物料大类")
    private String materialCategories;

    /**
     * 物料小类（1成品 2BOM）
     */
    @Excel(name = "物料小类", readConverterExp = "1=成品,2=BOM")
    private String materialSubclass;

    /**
     * SAP物料类型
     */
    @Excel(name = "SAP物料类型")
    private String materialType;

    /**
     * 计量单位（1立方米 2吨）
     */
    @Excel(name = "计量单位")
    private String materialUnit;

    /**
     * 单位工资(元)
     */
    @Excel(name = "单位工资(元)")
    private BigDecimal unitPrice;

    /**
     * 物料型号
     */
    @Excel(name = "物料型号")
    private String materialSpecifications;

    /**
     * 工厂编号
     */
    @Excel(name = "工厂编号")
    private String factoryCode;

    /**
     * 工位编号
     */
    @Excel(name = "工位编号")
    private String productLineCode;

    /**
     * 生产工位
     */
    @Excel(name = "生产工位")
    private String productLineName;

    /**
     * 是否标识
     */
    @Excel(name = "是否标识")
    private String isFlag;

    /**
     * 增量日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "增量日期", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date incrementDate;

    /**
     * 商品编码
     */
    @Excel(name = "商品编码")
    private String productCode;

    /**
     * 商品名称
     */
    @Excel(name = "商品名称")
    private String productName;

    public String getProductLineName() {
        return productLineName;
    }

    public void setProductLineName(String productLineName) {
        this.productLineName = productLineName;
    }

    public void setObjId(Long objId) {
        this.objId = objId;
    }

    public Long getObjId() {
        return objId;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialCategories(String materialCategories) {
        this.materialCategories = materialCategories;
    }

    public String getMaterialCategories() {
        return materialCategories;
    }

    public void setMaterialSubclass(String materialSubclass) {
        this.materialSubclass = materialSubclass;
    }

    public String getMaterialSubclass() {
        return materialSubclass;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }

    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }

    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setMaterialSpecifications(String materialSpecifications) {
        this.materialSpecifications = materialSpecifications;
    }

    public String getMaterialSpecifications() {
        return materialSpecifications;
    }

    public void setFactoryCode(String factoryCode) {
        this.factoryCode = factoryCode;
    }

    public String getFactoryCode() {
        return factoryCode;
    }

    public void setProductLineCode(String productLineCode) {
        this.productLineCode = productLineCode;
    }

    public String getProductLineCode() {
        return productLineCode;
    }

    public void setIsFlag(String isFlag) {
        this.isFlag = isFlag;
    }

    public String getIsFlag() {
        return isFlag;
    }

    public void setIncrementDate(Date incrementDate) {
        this.incrementDate = incrementDate;
    }

    public Date getIncrementDate() {
        return incrementDate;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductName() {
        return productName;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("objId", getObjId())
                .append("materialCode", getMaterialCode())
                .append("materialName", getMaterialName())
                .append("materialCategories", getMaterialCategories())
                .append("materialSubclass", getMaterialSubclass())
                .append("materialType", getMaterialType())
                .append("materialUnit", getMaterialUnit())
                .append("unitPrice", getUnitPrice())
                .append("materialSpecifications", getMaterialSpecifications())
                .append("factoryCode", getFactoryCode())
                .append("productLineCode", getProductLineCode())
                .append("isFlag", getIsFlag())
                .append("createBy", getCreateBy())
                .append("createTime", getCreateTime())
                .append("updateBy", getUpdateBy())
                .append("updateTime", getUpdateTime())
                .append("incrementDate", getIncrementDate())
                .append("productCode", getProductCode())
                .append("productName", getProductName())
                .toString();
    }
}
